==> 0.1.0.tar.gz: lib/components/buttons/varx_tertiary_button.dart <==
import 'package:flutter/material.dart';
import 'package:varx_design_system/components/buttons/content_button.dart';
import 'package:varx_design_system/components/buttons/loading_button_indicator.dart';

class VarxTertiaryButton extends StatelessWidget {
  const VarxTertiaryButton({
    Key? key,
    this.onTap,
    required this.label,
    this.prefixIcon,
    this.prefixIconData,
    this.suffixIcon,
    this.suffixIconData,
    this.loadingIndicator,
    this.isLoading = false,
    this.borderRadius,
    this.loadingColor,
    this.buttonStyle,
    this.primary,
    this.onprimary,
  }) : super(key: key);

  final Function()? onTap;
  final String label;
  final Widget? prefixIcon;
  final IconData? prefixIconData;
  final Widget? suffixIcon;
  final IconData? suffixIconData;
  final Widget? loadingIndicator;
  final bool isLoading;
  final BorderRadius? borderRadius;
  final Color? loadingColor;
  final ButtonStyle? buttonStyle;
  final Color? primary;
  final Color? onprimary;

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: onTap,
      style: buttonStyle ??
          ElevatedButton.styleFrom(
            primary: primary ?? Theme.of(context).colorScheme.primaryContainer,
            onPrimary: onprimary ?? Theme.of(context).colorScheme.primary,
            shape: RoundedRectangleBorder(
              borderRadius: borderRadius ?? BorderRadius.circular(8),
            ),
          ),
      child: isLoading
          ? LoadingButtonIndicator(loadingColor: loadingColor)
          : ContentButton(
              prefixIcon: prefixIconData != null
                  ? Icon(
                      prefixIconData,
                      size: 18,
                    )
                  : prefixIcon,
              label: label,
              suffixIcon: suffixIconData != null
                  ? Icon(
                      suffixIconData,
                      size: 18,
                    )
                  : suffixIcon,
            ),
    );
  }
}

==> 0.2.7.tar.gz: lib/components/buttons/varx_tertiary_button.dart <==
import 'package:flutter/material.dart';

import 'package:varx_design_system/components/buttons/content_button.dart';
import 'package:varx_design_system/components/buttons/loading_button_indicator.dart';

class VarxTertiaryButton extends StatelessWidget {
  const VarxTertiaryButton({
    Key? key,
    this.onTap,
    required this.label,
    this.prefixIcon,
    this.prefixIconData,
    this.suffixIcon,
    this.suffixIconData,
    this.loadingIndicator,
    this.isLoading = false,
    this.borderRadius,
    this.loadingColor,
    this.buttonStyle,
    this.primary,
    this.onprimary,
    this.fullWidth = true,
  }) : super(key: key);

  final Function()? onTap;
  final String label;
  final Widget? prefixIcon;
  final IconData? prefixIconData;
  final Widget? suffixIcon;
  final IconData? suffixIconData;
  final Widget? loadingIndicator;
  final bool isLoading;
  final BorderRadius? borderRadius;
  final Color? loadingColor;
  final ButtonStyle? buttonStyle;
  final Color? primary;
  final Color? onprimary;
  final bool fullWidth;

  @override
  Widget build(BuildContext context) {
    return ElevatedButton(
      onPressed: onTap,
      style: buttonStyle ??
          ElevatedButton.styleFrom(
            primary: primary ?? Theme.of(context).colorScheme.primaryContainer,
            onPrimary: onprimary ?? Theme.of(context).colorScheme.primary,
            shape: RoundedRectangleBorder(
              borderRadius: borderRadius ?? BorderRadius.circular(8),
            ),
          ),
      child: isLoading
          ? LoadingButtonIndicator(
              loadingColor: loadingColor,
              fullWidth: fullWidth,
            )
          : ContentButton(
              fullWidth: fullWidth,
              prefixIcon: prefixIconData != null
                  ? Icon(
                      prefixIconData,
                      size: 18,
                    )
                  : prefixIcon,
              label: label,
              suffixIcon: suffixIconData != null
                  ? Icon(
                      suffixIconData,
                      size: 18,
                    )
                  : suffixIcon,
            ),
    );
  }
}
